Skip to contents

This function checks if the directory path exists and creates it if it doesn't.

Usage

check_dir_path(dir_path)

Arguments

dir_path

A string specifying the path of the directory to check and create if necessary.

Value

None

Examples


if (FALSE) { # \dontrun{
check_dir_path("data/raw")
check_dir_path("data/processed")
} # }