Skip to contents

This function programmatically sends RDS files saved in a user-provided directory to a specified Google Drive location. The RDS files are converted to CSV format before being uploaded to Google Drive.

Usage

gdrive_send_rds_files(folder_with_files, gdrive_folder)

Arguments

folder_with_files

The local directory path containing the RDS files to be sent. Other file types can be in this location - they will be filtered out.

gdrive_folder

The folder on the GDrive you want data saved to - needs to be top level, do not make it multi-level.

Value

None (invisibly returns NULL)

Examples

if (FALSE) { # \dontrun{
# Provide the directory path containing the RDS files
folder_with_files <- "path/to/rds/files"

# Send the RDS files to Google Drive
gdrive_send_rds_files(folder_with_files)
} # }