Skip to contents

Use this function to knit RMD FlexDashboards to HTMLs and write them to new location and with a different name.

Usage

knit_dashboard(
  dashboard_name = "dashboard",
  dashboard_folder = "dashboard",
  doc_name = dashboard_name,
  overwrite = F,
  write_to_folder = "public"
)

Arguments

dashboard_name

string of RMD to knit - do not include `.RMD` extension.

dashboard_folder

string of folder name where RMD is located - default is `analysis`, do not include trailing `(/)`.

doc_name

string of knitted RMD name - default is `markdown_name`.

overwrite

boolean (`TRUE`/`FALSE`) indicating if file should be rewritten or if date suffix should be added to file name - default is `FALSE` which adds date suffix.

write_to_folder

string of folder name where RMD is written to - default is `public`.

Value

a knitted HTML document

Examples

#none