Skip to contents

Use this function to knit RMDs to HTMLs and write them to new location and with a different name.

Usage

knit_markdown(
  markdown_name,
  markdown_folder = "analysis",
  doc_name = markdown_name,
  overwrite = F,
  clean = TRUE,
  write_to_folder = "public"
)

Arguments

markdown_name

string of RMD to knit - do not include `.RMD` extension.

markdown_folder

string of folder name where RMD is located - default is `analysis`.

doc_name

string of knitted RMD name - default is `markdown_name`.

overwrite

boolean (`TRUE`/`FALSE`) indicating if file should be rewritten or if date suffix should be added to file name - default is `FALSE` which adds date suffix.

clean

boolean (`TRUE`/`FALSE`) - keep as default `TRUE`

write_to_folder

string of folder name where RMD is written to - default is `public`.

Value

a knitted HTML document

Examples

#none