Limit to Non-Negative Values
lmt0.RdThis function takes a numeric vector and replaces any negative values with zero.
Examples
lmt0(c(5, 6, 2, 0, -1))
#> [1] 5 6 2 0 0
lmt0.RdThis function takes a numeric vector and replaces any negative values with zero.
lmt0(c(5, 6, 2, 0, -1))
#> [1] 5 6 2 0 0