make_lag_col
make_lag_col.RdPre-filled lag function. This function should not be directly used, it is used inside of auto_make_lag_col function.
Usage
make_lag_col(lags = c(1, 7))make_lag_col.RdPre-filled lag function. This function should not be directly used, it is used inside of auto_make_lag_col function.
make_lag_col(lags = c(1, 7))