Skip to contents

This function copies an Rmd script template from the `gauntlet` package and writes it to a new location as defined by the user. Write-to folder locations must exist before running this code.

Usage

make_new_rmd(folder = "analysis", file_name = NULL)

Arguments

folder

a string name (defaults to `analysis` folder)

file_name

a string name (include .Rmd extension)

Value

an Rmd in the location and with the name chosen by the user

Examples

#none