Skip to contents

This function copies an R script template from the `gauntlet` package and writes it to a new location as defined by the user. Write-to folder locations must exist before running this code.

Usage

make_new_script(folder = "code", file_name = NULL)

Arguments

folder

a string name

file_name

a string name (include .r extentsion)

Value

a script in the location and with the name choosen by the user

Examples

#none