Skip to contents

Pre-filled rolling mean function. This function should not be directly used, it is used inside of auto_make_rMean_col() .

Usage

make_rMean_col(width, equal)

Arguments

width

integer input indicating size of sliding window used to calculate mean

equal

currently not used

Value

pre-filled function

Examples

if (FALSE) { # \dontrun{
#none
} # }