Quick Date Range
quick_date_rng.RdFunction returns min and max date values given month input by user. Mostly, to create date ranges for plots.
quick_date_rng.RdFunction returns min and max date values given month input by user. Mostly, to create date ranges for plots.