Read multiple csv files in singular folder.
read_csv_allFiles2.RdThis function can be used to read many files at once. Intended to read the same file that has been written multiple times using different date suffix. Example: same data that is queried daily and needs to be saved bu analyzed together.
Usage
read_csv_allFiles2(
data_location = "data",
specifically = NULL,
clean = F,
clean_string = NULL,
latest = F
)Arguments
- data_location
a string that defines which folder data is in - omit trailing `/`. Default is set to `/data/`.
- specifically
a string used to reprex filter files - use to limit which files are read.
- clean
a boolean to clean the data - BROKEN, always keep as default `FALSE`.
- clean_string
a string indicating a string that should be removed from file name when naming list entries.
- latest
a boolean (T/F) indicating if the function should only load the latest data - usually the latest by file name string date.