Skip to contents

This function generates a blank spacer row to create space between UI elements in Shiny applications. It is a convenience function that inserts a fluid row with an empty box having a specified height to create vertical space.

Usage

shiny_spacer_row(size)

Arguments

size

The height of the blank spacer row.

Value

A blank spacer row with the specified height.

See also

Examples

if (FALSE) { # \dontrun{
  # Create a spacer row with a specified height
  shiny_spacer_row(size = "20px")
} # }