Make a clean date string of current date with simple punctuation and syntax.
strg_clean_date.RdMake a clean date string of current date with simple punctuation and syntax.
strg_clean_date.RdMake a clean date string of current date with simple punctuation and syntax.