Skip to contents

Make a clean datetime string of current datetime with simple punctuation and syntax.

Usage

strg_clean_datetime(strip = FALSE)

Arguments

strip

A boolean to indicate where or not to truncate the datetime string to 15 characters, default F.

Value

character string of datetime using only underscores

Examples

if (FALSE) { # \dontrun{

clean_datetime()
} # }