Skip to contents

Takes a string and evaluates it as an R command.

Usage

strg_fun_eval(text)

Arguments

text

A character string representing the R command to evaluate.

Value

The result of evaluating the R command.

Examples

if (FALSE) { # \dontrun{
strg_fun_eval("1 + 1")
strg_fun_eval("mean(c(1, 2, 3))")

} # }