Skip to contents

This function replaces underscores with spaces and capitalizes the first letter of each word in a character string.

Usage

strg_pretty_char(col)

Arguments

col

A character string to make pretty.

Value

The pretty character string.

Details

Mostly used when making colnames or items in table pretty.

Examples

if (FALSE) { # \dontrun{
strg_pretty_char("hello_world")
strg_pretty_char("the_quick_brown_fox")

} # }