check_dir_path.Rd
This function checks if the directory path exists and creates it if it doesn't.
check_dir_path(dir_path)
A string specifying the path of the directory to check and create if necessary.
None
if (FALSE) { # \dontrun{ check_dir_path("data/raw") check_dir_path("data/processed") } # }