This function creates a directory with a specified prefix and the current date.
Usage
make_dir_prfx_date(directory_location, prefix)
Arguments
- directory_location
A string specifying the location of the directory to create.
- prefix
A string specifying the prefix to use for the directory name.
Value
A string specifying the path of the created directory.
Examples
if (FALSE) { # \dontrun{
#' make_dir_prfx_date("data/processed", "my_data_")
make_dir_prfx_date("data/raw", "my_data_")
} # }