Make new R script from template.
make_new_script.RdThis function copies an R script template from the `gauntlet` package and writes it to a new location as defined by the user. Write-to folder locations must exist before running this code.
make_new_script.RdThis function copies an R script template from the `gauntlet` package and writes it to a new location as defined by the user. Write-to folder locations must exist before running this code.