This function prompts the user with a message asking whether or not they want
to perform a specific action. The function accepts the user's response and
handles invalid input by prompting the user again.
Usage
robust_prompt_used(prompt)
Arguments
- prompt
A character string indicating the action to be performed.
Value
A logical value indicating whether or not the user elected to perform
the specified action. Returns TRUE if the user entered "Y", and FALSE if the
user entered "N".
Examples
if (FALSE) { # \dontrun{
robust_prompt_used("continue with the analysis")
} # }