This function takes the master Shiny input list at any given time and
extracts the list elements by matching their names based on a suffix and/or
a string pattern. It provides a convenient way for users to obtain the
instantaneous values of specific input elements for troubleshooting purposes.
Usage
shiny_get_list_items(input_list, suffix = NA, string, purrr = TRUE)
Arguments
- input_list
The Shiny input list to extract elements from.
- suffix
The optional suffix to filter input elements.
- string
The string pattern to filter input elements.
- purrr
Logical indicating whether to use purrr-style functions for filtering.
Value
A subset of the input list containing the matching elements.
Examples
if (FALSE) { # \dontrun{
# Extract input elements with a suffix and matching a string pattern
shiny_get_list_items(input_list = input, suffix = "numeric", string = "slider")
} # }