Create a blank spacer row for spacing between UI elements
shiny_spacer_row.RdThis function generates a blank spacer row to create space between UI elements in Shiny applications. It is a convenience function that inserts a fluid row with an empty box having a specified height to create vertical space.