strg_clean_datetime.Rd
Make a clean datetime string of current datetime with simple punctuation and syntax.
strg_clean_datetime(strip = FALSE)
A boolean to indicate where or not to truncate the datetime string to 15 characters, default F.
character string of datetime using only underscores
if (FALSE) { # \dontrun{ clean_datetime() } # }