Quickly clean a dataframe's column names
strg_col_clean.RdThis function cleans a data frame by removing empty rows and columns, converting column names to snake_case, and replacing a specified value with NA.
Examples
if (FALSE) { # \dontrun{
df <- data.frame(A = c(1, NA, 3), B = c("apple", "orange", ""), C = c("", "banana", ""))
strg_col_clean(df, "")
} # }