strg_fun_eval.Rd
Takes a string and evaluates it as an R command.
strg_fun_eval(text)
A character string representing the R command to evaluate.
The result of evaluating the R command.
if (FALSE) { # \dontrun{ strg_fun_eval("1 + 1") strg_fun_eval("mean(c(1, 2, 3))") } # }