Order factor levels numerically
strg_numeric_order.Rd`strg_numeric_order` orders factor levels numerically based on the values in the input vector. If `rev` is set to `TRUE`, the levels are reversed.
strg_numeric_order.Rd`strg_numeric_order` orders factor levels numerically based on the values in the input vector. If `rev` is set to `TRUE`, the levels are reversed.