Make a character string pretty
strg_pretty_char.RdThis function replaces underscores with spaces and capitalizes the first letter of each word in a character string.
strg_pretty_char.RdThis function replaces underscores with spaces and capitalizes the first letter of each word in a character string.