Make a number pretty for printing
strg_pretty_num.RdThis function formats a number to make it more readable. Large numbers are expressed in millions or billions and small numbers are not rounded.
strg_pretty_num.RdThis function formats a number to make it more readable. Large numbers are expressed in millions or billions and small numbers are not rounded.