Make rolling zscore attribute from timeseries.
ts_zscore.RdMake rolling zscore attribute from timeseries.
Arguments
- data
a dataframe containing the timeseries attribute
- grp
character list of attributes to group by
- width
integer value indicating widtch of window
- align
character indicating which side of value window will be aligned. Default is `right`, which only uses past values. Other options are `center` and `left`.
- threshold
integer indicating zscore away from center function will flag value as an outlier